==> engine-docs-3.12.87.jar: docs-for-nb/nosqlbench/getting_support.md <==
---
title: Getting Support
weight: 10
---

# Getting Support

In general, our goals with NoSQLBench are to make the help systems and examples wrap around the users like a suit of
armor, so that they feel capable of doing most things without having to ask for help. Please keep this in mind when
looking for personal support form our community, and help us find those places where the docs are lacking. Maybe you can
help us by adding some missing docs!

## Built-In Docs

The documentation for NoSQLBench is quite thorough. On the command line, you can see a list of built-in docs with the
command:

    nb help topics

To read any topic, simply use the command:

    nb help <topic>

The documentation system you are looking at right now includes the same docs you can find above already and more. They
are automatically included when NoSQLBench is built.

## General Feedback

These guidelines are mirrored at the
[Submitting Feedback](https://github.com/nosqlbench/nosqlbench/wiki/Submitting-Feedback) wiki page at the nosqlbench
project site, which is also where any `[Submit Feedback]` links should will take you.

## Bug Fixes

If you think you have found a bug, please
[file a bug report](https://github.com/nosqlbench/nosqlbench/issues/new?labels=bug). nosqlbench is actively used within
DataStax, and verified bugs will get attention as resources permit. Bugs reports which are more detailed, or bug reports
which include steps to reproduce will get attention first.

## Feature Requests

If you would like to see something in nosqlbench that is not there yet,please
[submit a feature request](https://github.com/nosqlbench/nosqlbench/issues/new?labels=feature).

## Documentation Requests

If you would like to see a specific nosqlbench or testing topic added to the guidebook, please
[request docs content](https://github.com/nosqlbench/nosqlbench/issues/new?labels=docs).

==> engine-docs-3.12.133.jar: docs-for-nb/nosqlbench/getting_support.md <==
---
title: Getting Support
weight: 10
---

# Getting Support

In general, our goals with NoSQLBench are to make the help systems and examples wrap around the users like a suit of
armor, so that they feel capable of doing most things without having to ask for help. Please keep this in mind when
looking for personal support form our community, and help us find those places where the docs are lacking. Maybe you can
help us by adding some missing docs!

## Built-In Docs

The documentation for NoSQLBench is quite thorough. On the command line, you can see a list of built-in docs with the
command:

    nb help topics

To read any topic, simply use the command:

    nb help <topic>

The documentation system you are looking at right now includes the same docs you can find above already and more. They
are automatically included when NoSQLBench is built.

## NoSQLBench Slack

There is a new slack channel at nosqlbench.slack.com. In order to access the slack channel, you'll need an invite. You
can get that through this simple form, which will send you an invite in email:
[Slack Invite](https://docs.google.com/forms/d/e/1FAIpQLSdUOJ8iAPqyxsLfh1nBBsKShI53RAeuzYW4bKExmRMWjj4ufQ/viewform).
This is just a simple google form that automates the invite process.

Please join it if you are a new or existing NoSQLBench user and help us get it going!




## General Feedback

These guidelines are mirrored at the
[Submitting Feedback](https://github.com/nosqlbench/nosqlbench/wiki/Submitting-Feedback) wiki page at the nosqlbench
project site, which is also where any `[Submit Feedback]` links should will take you.

## Bug Fixes

If you think you have found a bug, please
[file a bug report](https://github.com/nosqlbench/nosqlbench/issues/new?labels=bug). nosqlbench is actively used within
DataStax, and verified bugs will get attention as resources permit. Bugs reports which are more detailed, or bug reports
which include steps to reproduce will get attention first.

## Feature Requests

If you would like to see something in nosqlbench that is not there yet,please
[submit a feature request](https://github.com/nosqlbench/nosqlbench/issues/new?labels=feature).

## Documentation Requests

If you would like to see a specific nosqlbench or testing topic added to the guidebook, please
[request docs content](https://github.com/nosqlbench/nosqlbench/issues/new?labels=docs).
